# Generated by Django 5.2 on 2024-08-09 08:49

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("bionty", "0034_alter_source_unique_together"),
    ]

    operations = [
        migrations.AlterField(
            model_name="protein",
            name="gene_symbol",
            field=models.CharField(
                db_index=True, default=None, max_length=256, null=True
            ),
        ),
    ]
