# Generated by Django 5.2 on 2025-01-13 16:08

import django.db.models.deletion
import lamindb.base.fields
import lamindb.models
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("bionty", "0046_alter_cellline__aux_alter_cellmarker__aux_and_more"),
        ("lamindb", "0075_lamindbv1_part5"),
    ]

    operations = [
        migrations.RenameModel(
            old_name="FeatureSetCellMarker",
            new_name="SchemaCellMarker",
        ),
        migrations.RenameModel(
            old_name="FeatureSetGene",
            new_name="SchemaGene",
        ),
        migrations.RenameModel(
            old_name="FeatureSetPathway",
            new_name="SchemaPathway",
        ),
        migrations.RenameModel(
            old_name="FeatureSetProtein",
            new_name="SchemaProtein",
        ),
        migrations.RenameField(
            model_name="gene",
            old_name="feature_sets",
            new_name="schemas",
        ),
        migrations.RenameField(
            model_name="protein",
            old_name="feature_sets",
            new_name="schemas",
        ),
        migrations.RenameField(
            model_name="cellmarker",
            old_name="feature_sets",
            new_name="schemas",
        ),
        migrations.RenameField(
            model_name="pathway",
            old_name="feature_sets",
            new_name="schemas",
        ),
        migrations.RenameField(
            model_name="schemacellmarker",
            old_name="featureset",
            new_name="schema",
        ),
        migrations.RenameField(
            model_name="schemagene",
            old_name="featureset",
            new_name="schema",
        ),
        migrations.RenameField(
            model_name="schemapathway",
            old_name="featureset",
            new_name="schema",
        ),
        migrations.RenameField(
            model_name="schemaprotein",
            old_name="featureset",
            new_name="schema",
        ),
        migrations.AlterField(
            model_name="cellmarker",
            name="schemas",
            field=models.ManyToManyField(
                related_name="cell_markers",
                through="bionty.SchemaCellMarker",
                to="lamindb.schema",
            ),
        ),
        migrations.AlterField(
            model_name="gene",
            name="schemas",
            field=models.ManyToManyField(
                related_name="genes", through="bionty.SchemaGene", to="lamindb.schema"
            ),
        ),
        migrations.AlterField(
            model_name="pathway",
            name="schemas",
            field=models.ManyToManyField(
                related_name="pathways",
                through="bionty.SchemaPathway",
                to="lamindb.schema",
            ),
        ),
        migrations.AlterField(
            model_name="protein",
            name="schemas",
            field=models.ManyToManyField(
                related_name="proteins",
                through="bionty.SchemaProtein",
                to="lamindb.schema",
            ),
        ),
        migrations.AlterField(
            model_name="schemacellmarker",
            name="schema",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="+",
                to="lamindb.schema",
            ),
        ),
        migrations.AlterField(
            model_name="schemagene",
            name="schema",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="+",
                to="lamindb.schema",
            ),
        ),
        migrations.AlterField(
            model_name="schemapathway",
            name="schema",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="+",
                to="lamindb.schema",
            ),
        ),
        migrations.AlterField(
            model_name="schemaprotein",
            name="schema",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="+",
                to="lamindb.schema",
            ),
        ),
    ]
