# Generated by Django 5.2 on 2025-07-04 20:44

import django.db.models.deletion
import lamindb.base.fields
from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("bionty", "0054_alter_cellline_branch_alter_cellline_space_and_more"),
    ]

    operations = [
        migrations.RenameField(
            model_name="recordcellline",
            old_name="cellline",
            new_name="value",
        ),
        migrations.RenameField(
            model_name="recordcellmarker",
            old_name="cellmarker",
            new_name="value",
        ),
        migrations.RenameField(
            model_name="recordcelltype",
            old_name="celltype",
            new_name="value",
        ),
        migrations.RenameField(
            model_name="recorddevelopmentalstage",
            old_name="developmentalstage",
            new_name="value",
        ),
        migrations.RenameField(
            model_name="recorddisease",
            old_name="disease",
            new_name="value",
        ),
        migrations.RenameField(
            model_name="recordethnicity",
            old_name="ethnicity",
            new_name="value",
        ),
        migrations.RenameField(
            model_name="recordexperimentalfactor",
            old_name="experimentalfactor",
            new_name="value",
        ),
        migrations.RenameField(
            model_name="recordgene",
            old_name="gene",
            new_name="value",
        ),
        migrations.RenameField(
            model_name="recordorganism",
            old_name="organism",
            new_name="value",
        ),
        migrations.RenameField(
            model_name="recordpathway",
            old_name="pathway",
            new_name="value",
        ),
        migrations.RenameField(
            model_name="recordphenotype",
            old_name="phenotype",
            new_name="value",
        ),
        migrations.RenameField(
            model_name="recordprotein",
            old_name="protein",
            new_name="value",
        ),
        migrations.RenameField(
            model_name="recordtissue",
            old_name="tissue",
            new_name="value",
        ),
        migrations.AlterField(
            model_name="recordcellline",
            name="record",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="values_cell_line",
                to="lamindb.record",
            ),
        ),
        migrations.AlterField(
            model_name="recordcellmarker",
            name="record",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="values_cell_marker",
                to="lamindb.record",
            ),
        ),
        migrations.AlterField(
            model_name="recordcelltype",
            name="record",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="values_cell_type",
                to="lamindb.record",
            ),
        ),
        migrations.AlterField(
            model_name="recorddevelopmentalstage",
            name="record",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="values_developmental_stage",
                to="lamindb.record",
            ),
        ),
        migrations.AlterField(
            model_name="recorddisease",
            name="record",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="values_disease",
                to="lamindb.record",
            ),
        ),
        migrations.AlterField(
            model_name="recordethnicity",
            name="record",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="values_ethnicity",
                to="lamindb.record",
            ),
        ),
        migrations.AlterField(
            model_name="recordexperimentalfactor",
            name="record",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="values_experimental_factor",
                to="lamindb.record",
            ),
        ),
        migrations.AlterField(
            model_name="recordgene",
            name="record",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="values_gene",
                to="lamindb.record",
            ),
        ),
        migrations.AlterField(
            model_name="recordorganism",
            name="record",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="values_organism",
                to="lamindb.record",
            ),
        ),
        migrations.AlterField(
            model_name="recordpathway",
            name="record",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="values_pathway",
                to="lamindb.record",
            ),
        ),
        migrations.AlterField(
            model_name="recordphenotype",
            name="record",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="values_phenotype",
                to="lamindb.record",
            ),
        ),
        migrations.AlterField(
            model_name="recordprotein",
            name="record",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="values_protein",
                to="lamindb.record",
            ),
        ),
        migrations.AlterField(
            model_name="recordtissue",
            name="record",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="value_tissue",
                to="lamindb.record",
            ),
        ),
    ]
