# Generated by Django 5.1.12 on 2025-10-01 14:39

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("bionty", "0060_alter_cellline_is_locked_alter_cellmarker_is_locked_and_more"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="cellline",
            name="page",
        ),
        migrations.RemoveField(
            model_name="cellmarker",
            name="page",
        ),
        migrations.RemoveField(
            model_name="celltype",
            name="page",
        ),
        migrations.RemoveField(
            model_name="developmentalstage",
            name="page",
        ),
        migrations.RemoveField(
            model_name="disease",
            name="page",
        ),
        migrations.RemoveField(
            model_name="ethnicity",
            name="page",
        ),
        migrations.RemoveField(
            model_name="experimentalfactor",
            name="page",
        ),
        migrations.RemoveField(
            model_name="gene",
            name="page",
        ),
        migrations.RemoveField(
            model_name="organism",
            name="page",
        ),
        migrations.RemoveField(
            model_name="pathway",
            name="page",
        ),
        migrations.RemoveField(
            model_name="phenotype",
            name="page",
        ),
        migrations.RemoveField(
            model_name="protein",
            name="page",
        ),
        migrations.RemoveField(
            model_name="source",
            name="page",
        ),
        migrations.RemoveField(
            model_name="tissue",
            name="page",
        ),
    ]
